# Autogenerated by Astropy-affiliated package gwcs's setup.py on 2019-07-26 21:18:07 UTC
from __future__ import unicode_literals
import datetime

version = "0.11.0"
githash = "354da7cdafcfe7bcf7df5dc2682ff1f39541ec6c"


major = 0
minor = 11
bugfix = 0

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 7, 26, 21, 18, 7)
debug = False

astropy_helpers_version = "3.2.1"
